AdjustedHitsAtK
===============

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: AdjustedHitsAtK
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~AdjustedHitsAtK.binarize
      ~AdjustedHitsAtK.closed_expectation
      ~AdjustedHitsAtK.closed_variance
      ~AdjustedHitsAtK.increasing
      ~AdjustedHitsAtK.key
      ~AdjustedHitsAtK.name
      ~AdjustedHitsAtK.needs_candidates
      ~AdjustedHitsAtK.supported_rank_types
      ~AdjustedHitsAtK.supports_weights
      ~AdjustedHitsAtK.synonyms
      ~AdjustedHitsAtK.value_range

   .. rubric:: Methods Summary

   .. autosummary::

      ~AdjustedHitsAtK.__call__
      ~AdjustedHitsAtK.adjust
      ~AdjustedHitsAtK.expected_value
      ~AdjustedHitsAtK.extra_repr
      ~AdjustedHitsAtK.get_coefficients
      ~AdjustedHitsAtK.get_description
      ~AdjustedHitsAtK.get_link
      ~AdjustedHitsAtK.get_range
      ~AdjustedHitsAtK.get_sampled_values
      ~AdjustedHitsAtK.iter_extra_repr
      ~AdjustedHitsAtK.numeric_expected_value
      ~AdjustedHitsAtK.numeric_expected_value_with_ci
      ~AdjustedHitsAtK.numeric_variance
      ~AdjustedHitsAtK.numeric_variance_with_ci
      ~AdjustedHitsAtK.std
      ~AdjustedHitsAtK.variance

   .. rubric:: Attributes Documentation

   .. autoattribute:: binarize
   .. autoattribute:: closed_expectation
   .. autoattribute:: closed_variance
   .. autoattribute:: increasing
   .. autoattribute:: key
   .. autoattribute:: name
   .. autoattribute:: needs_candidates
   .. autoattribute:: supported_rank_types
   .. autoattribute:: supports_weights
   .. autoattribute:: synonyms
   .. autoattribute:: value_range

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: adjust
   .. automethod:: expected_value
   .. automethod:: extra_repr
   .. automethod:: get_coefficients
   .. automethod:: get_description
   .. automethod:: get_link
   .. automethod:: get_range
   .. automethod:: get_sampled_values
   .. automethod:: iter_extra_repr
   .. automethod:: numeric_expected_value
   .. automethod:: numeric_expected_value_with_ci
   .. automethod:: numeric_variance
   .. automethod:: numeric_variance_with_ci
   .. automethod:: std
   .. automethod:: variance
